package com.yuandian.common;

import java.time.Instant;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.MethodOrderer.OrderAnnotation;
import org.junit.jupiter.api.Order;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestMethodOrder;

import com.alibaba.nacos.api.exception.NacosException;

import lombok.extern.slf4j.Slf4j;
@Slf4j
@TestMethodOrder(OrderAnnotation.class)
public class ConfigTest {


    @BeforeAll
    static void beforeClass() {
        Config.ENV_TEST = "-test";
    }

    @Test
    @Order(1)
    void testConfigGet() throws Exception {
        Config.UseConfig((cnf) -> {
            /**
             *  nacos config 默认 group=yuandian dataId=dataflow
             *  key1:
             *      key2:
             *          path_value
             */
            log.info("{}",cnf.get("key1", "key2"));
			return null;
		});
    }

    @Test
    @Order(1)
    void testConfigSet() throws Exception {
        Config.UseConfig((cnf) -> {
            /**
             *  nacos config 默认 group=yuandian dataId=dataflow
             *  key1:
             *      key2:
             *          path_value
             */
            cnf.seek("key1", "key2").set("do_set");
            try {
                cnf.update(); // 每个写操作都需要执行 update()
            } catch (NacosException e) {
                e.printStackTrace();
            }
			return null;
		});
    }

    @Test
    @Order(1)
    void testConfigCreateKeys() throws Exception {
        Config.UseConfig((cnf) -> {
            /**
             *  nacos config 默认 group=yuandian dataId=dataflow
             *  create_keys: do_set
             */
            cnf.seek("create_keys").set("do_set");
            try {
                cnf.update(); // 每个写操作都需要执行 update()
            } catch (NacosException e) {
                e.printStackTrace();
            }
			return null;
		});
    }


    /**
     * 测试配置基础用法
     * @throws Exception
     */
    @Test
    @Order(2)
    void testUseConfig() throws Exception {
        
        Config.UseConfig((cnf) -> {
			log.info("{}",cnf.data);
            
            Assertions.assertEquals(cnf.get("key1", "key2"), "do_set");
            Instant now = Instant.now();
			cnf.data.put("use_config", now.toString());

            

			try {
				log.info("{}",cnf.update());
			} catch (NacosException e) {
				e.printStackTrace();
			}
			return null;
		});
    }

    @Test
    @Order(1)
    void testUseConfigUpdate() throws Exception {
        
        Config.UseConfig((cnf) -> {
 
            cnf.seek("create1","create2", "create3").createKeys().set("create_for_remove");;

			try {
				log.info("{}",cnf.update());
			} catch (NacosException e) {
				e.printStackTrace();
			}
			return null;
		});
    }

    @Test
    @Order(2)
    void testRemove() throws Exception {
        
        Config.UseConfig((cnf) -> {
            cnf.remove("create1", "create2");
			try {
				log.info("{}",cnf.update()); // 所有增加删除操作要最后同步到nacos. 都需要update
			} catch (NacosException e) {
				e.printStackTrace();
			}
            cnf.remove("create1");
			try {
				log.info("{}",cnf.update()); // 所有增加删除操作要最后同步到nacos. 都需要update
			} catch (NacosException e) {
				e.printStackTrace();
			}
            return null;
        });
    }
    @Test
    @Order(3)
    void testCreateKeys() throws Exception {
        
 
        Config.UseConfig((cnf) -> {
			log.info("{}",cnf.data); 
            cnf.seek("create1", "create2", "create3").createKeys().set(Instant.now().toString());;
			try {
				log.info("{}",cnf.update()); // 所有增加删除操作要最后同步到nacos. 都需要update
			} catch (NacosException e) {
				e.printStackTrace();
			}
			return null;
		});
    }
  
    @Test
    @Order(1)
    void testUpdate() throws Exception {
        
        Config.UseConfig((cnf) -> {
            Instant now = Instant.now();
			cnf.data.put("use_config", now.toString());
			try {
				log.info("{}",cnf.update());
			} catch (NacosException e) {
				e.printStackTrace();
			}
			return null;
		});
    }
    @Test
    @Order(1)
    void testLabelConfig() throws Exception {
        
        Config.UseConfig("org.fortest", (cnf)->{
            log.info("{}", cnf.get("test")); 
            Assertions.assertEquals(cnf.get("test"),  "groupAndDataId"); 
            return null;
        });
    }
}